%%
%% This is file `sjtu-math-font-newcm.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,math,otf,newcm')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {New Computer Modern math fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-math-font-newcm.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \RequirePackage { unicode-math }
    \bool_if:NTF \g__sjtu_upright_integral_bool
      {
        \setmathfont { NewCMMath-Book.otf }
          [ StylisticSet = 2 ]
      }
      { \setmathfont { NewCMMath-Book.otf } }
    \setmathfont { NewCMMath-Book.otf }
      [
        range        = { scr, bfscr },
        StylisticSet = 1
      ]
    \setmathrm
      { NewCM10 }
      [
        Extension    = .otf,
        SizeFeatures =
          {
            {
              Size        = -9,
              Font        = NewCM08-Book,
              ItalicFont  = NewCM08-BookItalic,
              SlantedFont = NewCM08-Book,
            },
            { Size        = 9- }
          },
        UprightFont         = *-Book,
        BoldFont            = *-Bold,
        ItalicFont          = *-BookItalic,
        BoldItalicFont      = *-BoldItalic,
        SlantedFont         = *-Book,
        SlantedFeatures     = { FakeSlant = 0.25 },
        BoldSlantedFont     = *-Bold,
        BoldSlantedFeatures = { FakeSlant = 0.25 }
      ]
    \setmathsf
      { NewCMSans10 }
      [
        Extension    = .otf,
        SizeFeatures =
          {
            {
              Size       = -9,
              Font       = NewCMSans08-Book,
              ItalicFont = NewCMSans08-BookOblique,
            },
            { Size       = 9- }
          },
        UprightFont    = *-Book,
        BoldFont       = *-Bold,
        ItalicFont     = *-BookOblique,
        BoldItalicFont = *-BoldOblique
      ]
    \setmathtt
      { NewCMMono10 }
      [
        Extension           = .otf,
        UprightFont         = *-Book,
        BoldFont            = *-Bold,
        ItalicFont          = *-BookItalic,
        BoldItalicFont      = *-BoldOblique,
        SlantedFont         = *-Book,
        SlantedFeatures     = { FakeSlant = 0.25 },
        BoldSlantedFont     = *-Bold,
        BoldSlantedFeatures = { FakeSlant = 0.25 }
      ]
  }
  { \__sjtu_fontset_error:nn { math } { newcm } }
\endinput
%%
%% End of file `sjtu-math-font-newcm.def'.
