%%
%% This is file `sjtu-cjk-font-hanyi.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sjtutex.dtx  (with options: `font,cjk,hanyi')
%% 
%%     Copyright (C) SJTUG
%%       2018--2026 Weijian Wu   <alexarawu@outlook.com>
%%       2022--2026 Zilong Li    <logcreative@outlook.com>
%%       2024--2026 Boshi Yuan   <nemoyuan2008@outlook.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either version 1.3c
%%     of this license or (at your option) any later version.
%%     The latest version of this license is in
%%       https://www.latex-project.org/lppl.txt
%%     and version 1.3c or later is part of all distributions of LaTeX
%%     version 2008 or later.
%% 
\GetIdInfo$Id: sjtutex.dtx 19925b2 2026-02-26 23:13:21 +0800 Alexara Wu <alexarawu@outlook.com> $
  {Hanyi CJK fonts definition (SJTUTeX)}
\ProvidesExplFile{sjtu-cjk-font-hanyi.def}
  {\ExplFileDate}{2.3.1}{\ExplFileDescription}
\__sjtu_if_engine_opentype:TF
  {
    \__sjtu_if_main_lang_ja:TF
      {
        \setCJKmainfont { HaranoAjiMincho }
          [
            Extension   = .otf ,
            UprightFont = *-Regular ,
            BoldFont    = *-Medium
          ]
        \setCJKsansfont { HaranoAjiGothic }
          [
            Extension   = .otf ,
            UprightFont = *-Medium ,
            BoldFont    = *-Bold
          ]
        \setCJKmonofont { HaranoAjiGothic }
          [
            Extension   = .otf ,
            UprightFont = *-Regular
          ]
        \setCJKfamilyfont { jamin  } { HaranoAjiMincho }
          [
            Extension   = .otf ,
            BoldFont    = *-Medium
          ]
        \setCJKfamilyfont { jagoth } { HaranoAjiGothic }
          [
            Extension   = .otf ,
            UprightFont = *-Medium ,
            BoldFont    = *-Bold
          ]
        \NewDocumentCommand \mincho   { } { \CJKfamily { jamin   } }
        \NewDocumentCommand \gothic   { } { \CJKfamily { jagoth  } }
      }
      {
        \setCJKmainfont { HYShuSongEr~S }
          [ BoldFont = HYZhongSong~S, ItalicFont = HYKaiTi~S ]
        \setCJKsansfont { HYZhongHei~S  } [ BoldFont = HYDaHei~S ]
        \setCJKmonofont { HYFangSong~S  }
      }
    \setCJKfamilyfont { zhsong } { HYShuSongEr~S }
      [ BoldFont = HYZhongSong~S ]
    \setCJKfamilyfont { zhhei  } { HYZhongHei~S  }
      [ BoldFont = HYDaHei~S     ]
    \setCJKfamilyfont { zhkai  } { HYKaiTi~S     }
    \setCJKfamilyfont { zhfs   } { HYFangSong~S  }
    \NewDocumentCommand \songti   { } { \CJKfamily { zhsong  } }
    \NewDocumentCommand \heiti    { } { \CJKfamily { zhhei   } }
    \NewDocumentCommand \fangsong { } { \CJKfamily { zhfs    } }
    \NewDocumentCommand \kaishu   { } { \CJKfamily { zhkai   } }
  }
  {
    \__sjtu_if_main_lang_ja:TF
      { \__sjtu_fontset_error:nn { cjk } { hanyi } }
      { \ctex_file_input:n { ctex-fontset-hanyi.def } }
  }
\endinput
%%
%% End of file `sjtu-cjk-font-hanyi.def'.
